@@ -1,4 +1,3 @@
-
 use strict;
 use warnings;
 
@@ -7,17 +6,18 @@ package HTML::Widget::Plugin::Image;
 use HTML::Widget::Plugin ();
 BEGIN { our @ISA = 'HTML::Widget::Plugin' };
 
+our $VERSION = '0.070';
+
 =head1 NAME
 
 HTML::Widget::Plugin::Image - an image object
 
-=head1 VERSION
+=head1 SYNOPSIS
 
-version 0.069
-
-=cut
-
-our $VERSION = '0.069';
+  $widget_factory->image({
+    src => 'http://example.com/example.jpg',
+    alt => 'An Example Image',
+  });
 
 =head1 DESCRIPTION
 
